[![Donate with Ethereum](https://en.cryptobadges.io/badge/small/0xf82d0ea7A2eDde6d30cAf8A1E6Fed09f726fD584)](https://en.cryptobadges.io/donate/0xf82d0ea7A2eDde6d30cAf8A1E6Fed09f726fD584)

# rarity-tools-scraper

A simple package remapping internal [rarity.tools](https://rarity.tools) functions and methods into easily accessible methods with full type support.
